@@ -38,6 +38,25 @@ def create_database(**kwargs: Any) -> None:
         log.info(f"Created AWS Glue database {name}.")
 
 
+def delete_crawler(**kwargs: Any) -> None:
+    """Safely delete the specified AWS Glue crawler. This however requires that the crawler is not running.
+
+    At minimum the `Name` keyword argument is required.
+
+    :param kwargs: These are forwarded to `delete_crawler`.
+    """
+    name = kwargs["Name"]
+    client = boto3.client("glue")
+
+    try:
+        response = client.delete_crawler(**kwargs)
+    except client.exceptions.EntityNotFoundException:
+        log.info(f"AWS Glue does not have a crawler named {name}.")
+    else:
+        assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
+        log.info(f"Deleted AWS Glue crawler {name}.")
+
+
 def delete_database(**kwargs: Any) -> None:
     """Safely delete the specified AWS Glue database.
 
